package de.fhhannover.inform.trust.ifmapj.messages;

import java.util.Collection;

import org.w3c.dom.Document;

import de.fhhannover.inform.trust.ifmapj.binding.Marshaller;

/**
 * Interface to access metadata containing elements.
 * 
 * An element containing a metadata element, as it is the case for
 * {@link PublishUpdate}, {@link PublishNotify} and {@link ResultItem} objects.
 * 
 * Access to metadata is provided through the {@link Document} class. That is,
 * metadata can be accessed using the org.w3c.dom functionality.
 * 
 * A {@link Marshaller} needs to create an metadata element and put the content
 * of all {@link Document} objects, beginning from the root node, into this
 * element.
 * 
 * @author aw
 */
public interface MetadataHolder extends IdentifierHolder {
	
	/**
	 * @param md the metadata object to be added.
	 * @throws NullPointerException if the metadata object is null;
	 */
	public void addMetadata(Document md);
	
	/**
	 * <b>Note:</b> The returned {@link Collection} is unmodifiable.
	 * 
	 * @return the list of {@link Document} objects representing metadata.
	 */
	public Collection<Document> getMetadata();
}
